﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Net.Security;
using System.ServiceModel;
using HeuristicLab.Services.UserManagement.DataTransfer;

namespace HeuristicLab.Services.UserManagement {
  [ServiceContract(ProtectionLevel = ProtectionLevel.EncryptAndSign)]
  public interface IUserManagementService {
    #region User
    [OperationContract]
    User GetUser(Guid id);

    [OperationContract]
    IEnumerable<User> GetUsers();

    [OperationContract]
    IEnumerable<User> GetUsersForApplication(Guid applicationId);

    [OperationContract]
    Guid AddUser(User user);

    [OperationContract]
    void DeleteUser(Guid id);

    [OperationContract]
    void UpdateUser(User user);

    [OperationContract]
    void SetRoleForUser(Guid roleId, Guid userId);

    [OperationContract]
    IEnumerable<User> GetUsersWithRole(Guid roleId);

    [OperationContract]
    void RemoveRoleFromUser(Guid roleId, Guid userId);

    [OperationContract]
    bool HasUserRole(Guid userId, Guid roleId);

    [OperationContract]
    User ResetPassword(string applicationName, string userName, string password);
    #endregion

    #region Role
    [OperationContract]
    Role GetRole(Guid id);

    [OperationContract]
    IEnumerable<Role> GetRoles();

    [OperationContract]
    IEnumerable<Role> GetRolesForApplication(Guid applicationId);

    [OperationContract]
    Guid AddRole(Role role);

    [OperationContract]
    void UpdateRole(Role role);

    [OperationContract]
    void DeleteRole(Guid id);

    [OperationContract]
    IEnumerable<Role> GetUserRoles(Guid userId);
    #endregion
  }
}
